from tkinter import *
from tkinter import messagebox

class Application(Frame):
    def __init__(self, master, *args, **kwargs):
        Frame.__init__(self, master, *args, **kwargs)
        self.createWidgets()

    def replaceText(self, text):
        self.display.delete(0, END)
        self.display.insert(0, text)

    def appendToDisplay(self, text):
        self.entryText = self.display.get()
        self.textLength = len(self.entryText)

        if self.entryText == "0":
            self.replaceText(text)
        else:
            self.display.insert(self.textLength, text)

    def calculateExpression(self):#python's calculate function 
        self.expression = self.display.get()
        self.expression = self.expression.replace("%", "/ 100")

        try:
            self.result = eval(self.expression)
            self.replaceText(self.result)
        except:
            messagebox.showinfo("ERROR", "Invalid input", icon="warning", parent=calculator)

    def clearText(self):#clears imput on pressing C on Calculator
        self.replaceText("0")

    def createWidgets(self):
        self.display = Entry(self, font=("Helvetica", 16), borderwidth=0, relief=RAISED, justify=RIGHT)
        self.display.insert(0, "0")
        self.display.grid(row=0, column=0, columnspan=5)

#This is the First Row
        self.sevenButton = Button(self, font=("Helvetica", 11), text="7", borderwidth=0, command=lambda: self.appendToDisplay("7"))
        self.sevenButton.grid(row=1, column=0, sticky="NWNESWSE")

        self.eightButton = Button(self, font=("Helvetica", 11), text="8", borderwidth=0, command=lambda: self.appendToDisplay("8"))
        self.eightButton.grid(row=1, column=1, sticky="NWNESWSE")

        self.nineButton = Button(self, font=("Helvetica", 11), text="9", borderwidth=0, command=lambda: self.appendToDisplay("9"))
        self.nineButton.grid(row=1, column=2, sticky="NWNESWSE")

        self.timesButton = Button(self, font=("Helvetica", 11), text="*", borderwidth=0, command=lambda: self.appendToDisplay("*"))
        self.timesButton.grid(row=1, column=3, sticky="NWNESWSE")

        self.clearButton = Button(self, font=("Helvetica", 11), text="C", borderwidth=0, command=lambda: self.clearText())
        self.clearButton.grid(row=1, column=4, sticky="NWNESWSE")

#This is the Second Row
        self.fourButton = Button(self, font=("Helvetica", 11), text="4", borderwidth=0, command=lambda: self.appendToDisplay("4"))
        self.fourButton.grid(row=2, column=0, sticky="NWNESWSE")

        self.fiveButton = Button(self, font=("Helvetica", 11), text="5", borderwidth=0, command=lambda: self.appendToDisplay("5"))
        self.fiveButton.grid(row=2, column=1, sticky="NWNESWSE")

        self.sixButton = Button(self, font=("Helvetica", 11), text="6", borderwidth=0, command=lambda: self.appendToDisplay("6"))
        self.sixButton.grid(row=2, column=2, sticky="NWNESWSE")

        self.divideButton = Button(self, font=("Helvetica", 11), text="/", borderwidth=0, command=lambda: self.appendToDisplay("/"))
        self.divideButton.grid(row=2, column=3, sticky="NWNESWSE")

        self.percentageButton = Button(self, font=("Helvetica", 11), text="%", borderwidth=0, command=lambda: self.appendToDisplay("%"))
        self.percentageButton.grid(row=2, column=4, sticky="NWNESWSE")

#This is the Third Row
        self.oneButton = Button(self, font=("Helvetica", 11), text="1", borderwidth=0, command=lambda: self.appendToDisplay("1"))
        self.oneButton.grid(row=3, column=0, sticky="NWNESWSE")

        self.twoButton = Button(self, font=("Helvetica", 11), text="2", borderwidth=0, command=lambda: self.appendToDisplay("2"))
        self.twoButton.grid(row=3, column=1, sticky="NWNESWSE")

        self.threeButton = Button(self, font=("Helvetica", 11), text="3", borderwidth=0, command=lambda: self.appendToDisplay("3"))
        self.threeButton.grid(row=3, column=2, sticky="NWNESWSE")

        self.minusButton = Button(self, font=("Helvetica", 11), text="-", borderwidth=0, command=lambda: self.appendToDisplay("-"))
        self.minusButton.grid(row=3, column=3, sticky="NWNESWSE")

        self.equalsButton = Button(self, font=("Helvetica", 11), text="=", borderwidth=0, command=lambda: self.calculateExpression())
        self.equalsButton.grid(row=3, column=4, sticky="NWNESWSE", rowspan=2)

#This is the Fourth Row
        self.zeroButton = Button(self, font=("Helvetica", 11), text="0", borderwidth=0, command=lambda: self.appendToDisplay("0"))
        self.zeroButton.grid(row=4, column=0, columnspan=2, sticky="NWNESWSE")

        self.dotButton = Button(self, font=("Helvetica", 11), text=".", borderwidth=0, command=lambda: self.appendToDisplay("."))
        self.dotButton.grid(row=4, column=2, sticky="NWNESWSE")

        self.plusButton = Button(self, font=("Helvetica", 11), text="+", borderwidth=0, command=lambda: self.appendToDisplay("+"))
        self.plusButton.grid(row=4, column=3, sticky="NWNESWSE")
def calculator():
    calc = Tk()
    calc.title("CALCULATOR")
    calc.resizable(0, 1)
    app = Application(calc).grid()        
    calc.mainloop()


import tkinter
import os
from tkinter import *
from tkinter.messagebox import *
from tkinter.filedialog import *

class Notepad:

    #variables
    __root = Tk()

    #default window width and height
    __thisWidth = 300
    __thisHeight = 300
    __thisTextArea = Text(__root)
    __thisMenuBar = Menu(__root)
    __thisFileMenu = Menu(__thisMenuBar,tearoff=0)
    __thisEditMenu = Menu(__thisMenuBar,tearoff=0)
    __thisHelpMenu = Menu(__thisMenuBar,tearoff=0)
    __thisScrollBar = Scrollbar(__thisTextArea)
    __file = None

    def __init__(self,**kwargs):
        #initialization

        #set icon
        try:
                self.__root.wm_iconbitmap("Notepad.ico") #GOT TO FIX THIS ERROR (ICON)
        except:
                pass

        #set window size (the default is 300x300)

        try:
            self.__thisWidth = kwargs['width']
        except KeyError:
            pass

        try:
            self.__thisHeight = kwargs['height']
        except KeyError:
            pass

        #set the window text
        self.__root.title("Untitled - Notepad")

        #center the window
        screenWidth = self.__root.winfo_screenwidth()
        screenHeight = self.__root.winfo_screenheight()

        left = (screenWidth / 2) - (self.__thisWidth / 2)
        top = (screenHeight / 2) - (self.__thisHeight /2)

        self.__root.geometry('%dx%d+%d+%d' % (self.__thisWidth, self.__thisHeight, left, top))

        #to make the textarea auto resizable
        self.__root.grid_rowconfigure(0,weight=1)
        self.__root.grid_columnconfigure(0,weight=1)

        #add controls (widget)

        self.__thisTextArea.grid(sticky=N+E+S+W)

        self.__thisFileMenu.add_command(label="New",command=self.__newFile)
        self.__thisFileMenu.add_command(label="Open",command=self.__openFile)
        self.__thisFileMenu.add_command(label="Save",command=self.__saveFile)
        self.__thisFileMenu.add_separator()
        self.__thisFileMenu.add_command(label="Exit",command=self.__quitApplication)
        self.__thisMenuBar.add_cascade(label="File",menu=self.__thisFileMenu)

        self.__thisEditMenu.add_command(label="Cut",command=self.__cut)
        self.__thisEditMenu.add_command(label="Copy",command=self.__copy)
        self.__thisEditMenu.add_command(label="Paste",command=self.__paste)
        self.__thisMenuBar.add_cascade(label="Edit",menu=self.__thisEditMenu)

        self.__thisHelpMenu.add_command(label="About Notepad",command=self.__showAbout)
        self.__thisMenuBar.add_cascade(label="Help",menu=self.__thisHelpMenu)

        self.__root.config(menu=self.__thisMenuBar)

        self.__thisScrollBar.pack(side=RIGHT,fill=Y)
        self.__thisScrollBar.config(command=self.__thisTextArea.yview)
        self.__thisTextArea.config(yscrollcommand=self.__thisScrollBar.set)
    
        
    def __quitApplication(self):
        self.__root.destroy()
        #exit()

    def __showAbout(self):
        showinfo("Notepad"," ")

    def __openFile(self):
        
        self.__file = askopenfilename(defaultextension=".txt",filetypes=[("All Files","*.*"),("Text Documents","*.txt")])

        if self.__file == "":
            #no file to open
            self.__file = None
        else:
            #try to open the file
            #set the window title
            self.__root.title(os.path.basename(self.__file) + " - Notepad")
            self.__thisTextArea.delete(1.0,END)

            file = open(self.__file,"r")

            self.__thisTextArea.insert(1.0,file.read())

            file.close()

        
    def __newFile(self):
        self.__root.title("Untitled - Notepad")
        self.__file = None
        self.__thisTextArea.delete(1.0,END)

    def __saveFile(self):

        if self.__file == None:
            #save as new file
            self.__file = asksaveasfilename(initialfile='Untitled.txt',defaultextension=".txt",filetypes=[("All Files","*.*"),("Text Documents","*.txt")])

            if self.__file == "":
                self.__file = None
            else:
                #try to save the file
                file = open(self.__file,"w")
                file.write(self.__thisTextArea.get(1.0,END))
                file.close()
                #change the window title
                self.__root.title(os.path.basename(self.__file) + " - Notepad")
                
            
        else:
            file = open(self.__file,"w")
            file.write(self.__thisTextArea.get(1.0,END))
            file.close()

    def __cut(self):
        self.__thisTextArea.event_generate("<<Cut>>")

    def __copy(self):
        self.__thisTextArea.event_generate("<<Copy>>")

    def __paste(self):
        self.__thisTextArea.event_generate("<<Paste>>")

    def run(self):

        #run main application
        self.__root.mainloop()

def notepad():
    note = Notepad(width=600,height=400)
    note.run()




import tkinter
import os
import pickle

from tkinter import ttk,scrolledtext
from datetime import datetime

root = None

class TodoData(object):
    def __init__(self):
        self.database_name="pytodo_1.tdb"
        self.data_path=os.getcwd()+"/"+self.database_name
        self.__check_database()
        
    def __check_database(self):
        """it will check if "pytodo_1.tdb" exists or not if not then
it will create it"""
        if not os.path.exists(self.data_path):
            with open(self.data_path,"wb") as tdb:
                pickle.dump([],tdb)
    def load_tdb(self):
        """method to load data from database"""
        with open(self.data_path,"rb") as tdb:
            return pickle.load(tdb)
    def write_tdb(self, tdbList:"list"):
        """writing on database"""
        with open(self.data_path,"wb") as tdb:
            pickle.dump(tdbList,tdb)        
    

class Main_UI(tkinter.Frame):
    def __init__(self,root=tkinter.Tk):
        tkinter.Frame.__init__(self,root)
        self.root=root
        self.root.title("PyTodo")
        self.root.resizable(1,0)
        self.root.minsize(580,352)
        self.root.bind("<Return>",self.root_bind)
        self.root.bind("<Delete>",self.root_bind_del)
        self.root.protocol("WM_DELETE_WINDOW",self.__exit_handle) #exit button handler
        
        self.column=["SN","Date","Task","Duration","Progress%","Status","Message"]
        self.column_size=[7,55,100,38,50,60,10]
        self.date=datetime.now().strftime("%d/%m-%H:%M")
        self.total_item=0

        
        self.entryVar=[tkinter.StringVar() for x in range(3)]
        self.entryVar[1].trace('w',self.type_handle)
        self.entryVar[2].trace('w',self.progress_handle)
        
        self.clear_switch=0
        
        #---database---
        self.database=TodoData()
        self.tdb=self.database.load_tdb()
        
        #--frame------
        self.todo_frame=tkinter.LabelFrame(self.root,text="To Do")
        self.todo_frame.pack(side="left",padx=2,pady=2,fill="x",expand=True)
        
        self.message_frame=tkinter.LabelFrame(self.root,text="Message")
        self.message_frame.pack(side="left")
        
        self.input_frame=tkinter.Frame(self.todo_frame)
        
        self.button_frame=tkinter.Frame(self.todo_frame)
        
        #---treeview---
        self.tree=ttk.Treeview(self.todo_frame,height=11)
        self.tree.pack(padx=2,pady=3,fill="x")
        
        self.tree["columns"]=self.column
        self.tree["show"]="headings"
        self.tree["displaycolumns"]=self.column[:-1]
        self.tree.bind("<<TreeviewSelect>>",self.treeview_bind)
        
        #---treeview tag------
        self.tree.tag_configure("green",foreground="green")
        self.tree.tag_configure("gray",foreground="light gray")
        self.tree.tag_configure("red",foreground="red")
        self.tree.tag_configure("orange",foreground="orange")
        
        for index,col in enumerate(self.column):
            self.tree.column(col,width=self.column_size[index])
            self.tree.heading(col,text=col,command=lambda identity=col: self.heading_bind(identity))
        self.input_frame.pack(anchor="se")
        self.button_frame.pack(anchor="se")
        
        #---scrolled textbox----
        self.stext=scrolledtext.ScrolledText(self.message_frame,width=27,height=23,font="consolas 9")
        self.stext.pack(padx=2,pady=2)
        
        #----input entry-----
        self.task_label=tkinter.Label(self.input_frame,text="Task")
        self.task_label.grid(row=0,column=0)
        self.task_entry=tkinter.Entry(self.input_frame,width=45,textvariable=self.entryVar[0])
        self.task_entry.grid(row=1,column=0,pady=2)
        
        self.dur_label=tkinter.Label(self.input_frame,text="Duration in day")
        self.dur_label.grid(row=0,column=1)
        self.dur_entry=tkinter.Entry(self.input_frame,width=15,textvariable=self.entryVar[1])
        self.dur_entry.grid(row=1,column=1,pady=2)        
        
        self.prog_label=tkinter.Label(self.input_frame,text="Progress %")
        self.prog_label.grid(row=0,column=2)
        self.prog_entry=tkinter.Entry(self.input_frame,width=10,textvariable=self.entryVar[2])
        self.prog_entry.grid(row=1,column=2,pady=2)         
            
        #---button-------
        self.insert_button=tkinter.Button(self.button_frame,text="Insert",width=10,command=self.insert_command)
        self.Update_button=tkinter.Button(self.button_frame,text="Update",width=10,command=self.update_command)
        self.Delete_button=tkinter.Button(self.button_frame,text="Delete",width=10,command=self.delete_command)
        self.Clear_button=tkinter.Button(self.button_frame,text="Clear",width=10,command=self.clear_command)
        
        self.Clear_button.pack(side="left",padx=3,pady=3)
        self.insert_button.pack(side="left",padx=3,pady=3)
        self.Update_button.pack(side="left",padx=3,pady=3)
        self.Delete_button.pack(side="left",padx=3,pady=3)
        
        self.__starting()
    
    def __make_list(self) -> [[]]:
        """this method collect data from treeview and then create multidimentional list
        it will also sort the data in a defined order. (need to polish it more)"""
        incomplete=[]
        complete=[]
        failed=[]
        note=[]
        invalid=[]
        all_item=self.tree.get_children()
        for item in all_item:
            values=self.tree.item(item)["values"]
            if "Done" in values:
                complete.append(values)
            elif "Failed" in values:
                failed.append(values)
            elif "Invalid" in values:
                invalid.append(values)
            elif "Note" in values:
                note.append(values)            
            else:
                incomplete.append(values)
        temp=[]
        temp2={}
        for task in incomplete:
            duration=task[-2]
            duration=float(duration[:duration.index("d")-1])
            if duration not in temp:
                temp.append(duration)
            if duration not in temp2:
                temp2[duration]=[task]
            else:
                temp2[duration].append(task)
        temp.sort()
        incomplete=[]
        for f in temp:
            extract=(temp2[f]) #[[],[]..]
            for item in extract:
                incomplete.append(item)
        
        all_item=incomplete+failed+complete+note+invalid #changing this order will affect how item will listed in next time.
        return all_item                                  #if we restart the program first incomplete task will be shown
    
    def __starting(self):
        """this method will call at starting point, it will read data from database then insert in treeview"""
        message=""
        me="welcome to PyTodo\nOrganize your task easily\n\n"
        for num,task in enumerate(self.tdb):
            date=task[1]
            duration=task[3]
            progress=task[-3]
            task_name=task[2]
            
            progress,status,tag=self.__status(duration, progress, date, task_name) #generating status and color tag
            if tag=="orange":
                message+=task_name+", "
            task.pop(-2)
            task.insert(-1,status)
            task.pop(0)
            task.insert(0,num+1)            
            self.tree.insert("",num,values=task,tag=tag)            
            self.total_item+=1
        if message:
            message+="\nFocus on this task before you failed to complete"
        elif self.total_item==0:
            message="1. press \"clear\", Then insert your task name in task entry, you can make necessary note in this messagebox\n\n2. Type how long it will take to complete in day/s, no duration means it is a note\n\n3. Type a estimate value of your progress and press update to update the data\n\n4. select task from treeview then press delete to delete it"
        self.stext.insert("end",me+message)    
    
    def __elapsed_time(self,date,current_date):
        """every item has its own assigned date, we can get elapsed time by subtracting from current date"""
        
        day_old=datetime.strptime(date,"%d/%m-%H:%M")
        day_Current=datetime.strptime(current_date,"%d/%m-%H:%M")
        day_passed=day_Current-day_old
        day_passed=(abs(day_passed.days)*86400)+day_passed.seconds
        return day_passed/86400 #days. ex: <float> 3.5 days
    
    def __time_update(self):
        self.date=datetime.now().strftime("%d/%m-%H:%M")
        
    def __status(self,duration,progress,date,task):
        """this method generate status data and define treeview color tag"""
        status=""
        tag=""
        if duration:
            x=self.__elapsed_time(date, self.date)
            time_left=round(int(duration)-self.__elapsed_time(date, self.date),2)
            if not progress:
                progress=0
            if time_left>1:
                status=str(time_left)+" days left"
            elif time_left<=1 and time_left>0:
                status=str(time_left)+" day left"
                tag="orange"
            elif time_left<=0:
                status="Failed"
                tag="red"
        elif task:
            status="Note"
        else:
            status="Invalid"
            tag="gray"
        
        if status!="Invalid" and status!="Note" and int(progress)==100:
            tag="green"
            status="Done"
        return (progress,status,tag)
    
    #------------------------------button commands-----------------------     
    def insert_command(self):
        """collect data from all input and then insert in treeview"""
        self.__time_update()
        self.total_item+=1
        serial=self.total_item
        task=self.entryVar[0].get()
        duration=self.entryVar[1].get()
        progress=self.entryVar[2].get()
        date=self.date
        message=self.stext.get("1.0","end-1c")
        if "welcome to" in message:
            message=""
        progress,status,tag=self.__status(duration, progress, date, task)
        
        item=self.tree.insert('',serial,values=(serial,date,task,duration,progress,status,message),tag=tag)
        self.tree.see(item)    
                  
    def update_command(self):
        """only work if clear switch is not pressed and item in treeview is in focus"""
        if not self.clear_switch and self.tree.focus():
            task=self.entryVar[0].get()
            duration=self.entryVar[1].get()
            progress=self.entryVar[2].get()
            message=self.stext.get("1.0","end-1c")
            focused_item=self.tree.focus()
            values=self.tree.item(focused_item)["values"]
            serial=values[0]
            date=values[1]
            
            progress,status,tag=self.__status(duration, progress, date, task)
            
            self.tree.item(focused_item,values=(serial,date,task,duration,progress,status,message),tag=tag)            
            

    def delete_command(self):
        """method for del key event and delete button press"""
        focused_item=self.tree.focus()
        allitem=self.tree.get_children()
        begin=0
        for num,item in enumerate(allitem):
            if item==focused_item: 
                begin=1
            if begin:
                cur_val=self.tree.item(item)["values"]
                cur_val.pop(0)
                cur_val.insert(0,num)
                self.tree.item(item,values=cur_val)
        if focused_item:
            self.tree.delete(focused_item)
            self.total_item-=1
        
    def clear_command(self):
        """clear entrys and scrolledtext"""
        self.clear_switch=1
        for var in self.entryVar:
            var.set("")
        self.stext.delete("1.0","end")
        self.task_entry.focus()
    
    
    
    #--------------event handling functions---------------
    def progress_handle(self,*args):
        """entry type handler to prevent user to input illeagal data and force them to keep number between 0 and 100"""
        temp=self.entryVar[2].get()
        if temp.isdigit():
            if int(temp)>100:
                self.entryVar[2].set("100")
        else:
            self.entryVar[2].set("")
            
    def type_handle(self,*args):
        """entry type handler to prevent user to input illeagal data"""
        temp=self.entryVar[1].get()
        if not temp.isdigit():
            self.entryVar[1].set("")
    
    def root_bind(self,arg):
        """enter key binding, whether enter key call update function or insert function"""
        if not self.clear_switch and self.tree.focus():
            self.update_command()
        else:
            self.insert_command()
    def root_bind_del(self,arg):
        """root del key binding, little trick to avoid item deletion in treeview """
        if not type(self.root.focus_get())==tkinter.scrolledtext.ScrolledText:
            self.delete_command()
            
    def heading_bind(self,identity:'id of heading'):
        """it will sort data accordingly"""
        print(identity,"Not yet implemented")
    
    def treeview_bind(self,arg):
        """treeview item click bind, if any item is in focus, editable data will be in entry and scrolltext box"""
        self.clear_command()
        self.clear_switch=0
        focused_item=self.tree.focus()
        values=self.tree.item(focused_item)["values"]
        for num,var in enumerate(self.entryVar):
            var.set(values[num+2])
        self.stext.insert("end",values[-1])    
    
    def __exit_handle(self):
        """this method calls necessary to save/update entire data in database before closing"""
        tdb=self.__make_list()
        self.database.write_tdb(tdb)
        root.destroy()

            
def todo():
    global root
    root=tkinter.Tk()
    ui=Main_UI(root)
    ui.mainloop()


import tkinter
import time
from tkinter import scrolledtext

class Clock(tkinter.Label):
    def __init__(self, parent=None, seconds=True):
        tkinter.Label.__init__(self, parent)

        self.display_seconds = seconds
        if self.display_seconds:
            self.time = time.strftime('%I:%M:%S')
        else:
            self.time = time.strftime('%I:%M %p').lstrip('0')
        self.display_time = self.time
        self.configure(text=self.display_time)

        self.after(200, self.tick)

    def tick(self):
        if self.display_seconds:
            new_time = time.strftime('%I:%M:%S')
        else:
            new_time = time.strftime('%I:%M %p').lstrip('0')
        if new_time != self.time:
            self.time = new_time
            self.display_time = self.time
            self.config(text=self.display_time)
        self.after(200, self.tick)

def timestamp():
    print(time.strftime("%I:%M:%S"))

def clock():

    window = tkinter.Tk()
    frame = tkinter.Frame(window, width=800, height=800)
    frame.pack()

    tkinter.Label(frame, text="Current time: ").pack()

    text = scrolledtext.ScrolledText(frame, height=10)
    text.pack()

    clock1 = Clock(frame)
    clock1.pack()
    clock1.configure(bg='white', fg='black', font=("helvetica", 65))

    tkinter.Label(frame, text=" ").pack()

    b = tkinter.Button(frame, text='Quit', command=quit)
    b.pack(side=tkinter.RIGHT)
    b2 = tkinter.Button(frame, text='Current Time', command=lambda :text.insert("end", time.strftime("%I:%M:%S")+'\n'))
    b2.pack(side=tkinter.LEFT)

    window.mainloop()


from tkinter import *
import tkinter as tk
from datetime import datetime
import requests
from tkinter import messagebox

class Weather():

        def weather_report(self):
                
                self.url = "http://api.openweathermap.org/data/2.5/weather?q="
                self.cityname =  self.loc.get(1.0,END)
                self.api_key = '64f61566457c1a48b4f301389ba59786'
                self.data = requests.get(self.url+self.cityname+'&appid='+self.api_key).json()
                

                if self.data['cod'] == '404':
                        messagebox.showerror('Error','City Not Found !!')
                else:
                         self.location['text'] = self.data['name'] + "," + self.data['sys']['country']
                         self.c = self.data['main']['temp_max'] - 273.15
                         self.f = self.c*9/5+32
                         self.weather['text'] = self.data['weather'][0]['main']
                         self.weather['font'] = ('verdana',20,'bold')
                         self.temperature['text'] = f'{self.c}°C \n {self.f}°F'
                         self.temperature['font'] = ('verdana',15,'bold')
                         self.humidity['text'] = self.data['main']['humidity']
                         self.humidity['font'] = ('verdana',15,'bold')
                         self.pressure['text'] = self.data['main']['pressure']
                         self.pressure['font'] = ('verdana',15,'bold')
                         
        
        
        def __init__(self):
                self.root = tk.Tk()
                self.root.geometry('500x300')
                self.root.title("Weather Application")
                self.root.maxsize(500,300)
                self.root.minsize(500,300)

                self.header = Label(self.root,width=100,height=2,bg="#00274c")
                self.header.place(x=0,y=0)

                self.font = ('verdana',10,'bold')

                self.date = Label(self.root,text=datetime.now().date(),bg="#00274c",fg="white",font=self.font)
                self.date.place(x=400,y=5)

                self.heading = Label(self.root,text="Weather Report",bg="#00274c",fg="white",font=self.font)
                self.heading.place(x=180,y=5)


                self.location = Label(self.root,text="NA-/",bg="#00274c",fg="white",font=self.font)
                self.location.place(x=10,y=5)


                self.name = Label(self.root,text="City Name",fg="#00274c",font=self.font)
                self.name.place(x=140,y=45)

                self.loc = Text(self.root,width=25,height=2)
                self.loc.place(x=140,y=70)

                self.button = Button(self.root,text="Search",bg="#00274c",fg="white",font=self.font,relief=RAISED,borderwidth=3,command=self.weather_report)
                self.button.place(x=350,y=73)

                self.line1 = Label(self.root,bg="#00274c",width=20,height=0)
                self.line1.place(x=0,y=150)
                self.line2 = Label(self.root,bg="#00274c",width=20,height=0)
                self.line2.place(x=360,y=150)

                self.report = Label(self.root,text="Weather Report",bg="#00274c",fg="white",font=self.font,padx=10)
                self.report.place(x=180,y=150)


                self.weather = Label(self.root,text="NA/-",fg="#00274c",font=self.font)
                self.weather.place(x=90,y=230)


                self.temperature = Label(self.root,text="NA/-",fg="#00274c",font=self.font)
                self.temperature.place(x=200,y=230)

                
                self.humidity = Label(self.root,text="NA/-",fg="#00274c",font=self.font)
                self.humidity.place(x=310,y=230)
              
                self.pressure = Label(self.root,text="NA/-",fg="#00274c",font=self.font)
                self.pressure.place(x=380,y=230)

                self.root.mainloop()


def wheather():
        Weather()



import random
import string
from tkinter import *

# Specify the snake & the characters it uses
HEAD_CHAR = "|"
FOOD_CHARS = string.ascii_letters

# Application
class Application:
  # Basic setup variables
  TITLE = "Snake"
  SIZE = 300, 300

  def __init__(self, master):
    # Initializing the variables
    self.master = master
    self.head = None
    self.head_position = None
    self.segments = []
    self.segments_positions = []
    self.food = None
    self.food_position = None
    self.direction = None
    self.moved = True
    self.running = False

    # Run the init function
    self.init()

  def init(self):
    self.master.title(self.TITLE)

    # Creating the canvas
    self.canvas = Canvas(self.master)
    self.canvas.grid(sticky=NSEW)

    # Creating the start button
    self.start_button = Button(self.master, text="Start", command=self.on_start)
    self.start_button.grid(sticky=EW)

    # Bind the movements keys to the canvas
    self.master.bind("w", self.on_up)
    self.master.bind("a", self.on_left)
    self.master.bind("s", self.on_down)
    self.master.bind("d", self.on_right)

    # Configure the size of the canvas
    self.master.columnconfigure(0, weight=1)
    self.master.rowconfigure(0, weight=1)
    self.master.resizable(width=False, height=False)
    self.master.geometry("%dx%d" % self.SIZE)

  # When start button is clicked
  def on_start(self):
    # Reset Everything
    self.reset()
    # Check if the game is already running
    if self.running:
      self.running = False
      # Changing the text displayed on the button
      self.start_button.configure(text="Start")
    else:
      self.running = True
      # Changing the text displayed on the button
      self.start_button.configure(text="Stop")
      # Starting the game
      self.start()

  # Reset function for the game
  def reset(self):
    # Delete all the snake's body
    del self.segments[:]
    del self.segments_positions[:]
    self.canvas.delete(ALL)

  # Start function for the game
  def start(self):
    # Taking in the info of the canvas (width & height)
    width = self.canvas.winfo_width()
    height = self.canvas.winfo_height()

    # Draw the game screen
    self.canvas.create_rectangle(10, 10, width - 10, height - 10)
    self.direction = random.choice('wasd')
    head_position = [round(width / 2, -1), round(height / 2, -1)]
    self.head = self.canvas.create_text(tuple(head_position), text=HEAD_CHAR)
    self.head_position = head_position

    # Calling the functions to start the game - spawning food & updating
    self.spawn_food()
    self.tick()

  # Function for spawning the food
  def spawn_food(self):
    # get the width & height of canvas
    width = self.canvas.winfo_width()
    height = self.canvas.winfo_height()

    # check if the food is spawned on the snake's body
    positions = [tuple(self.head_position), self.food_position] + self.segments_positions
    position = round(random.randint(20, width - 20), -1), round(random.randint(20, height - 20), -1)

    # if the newly generated food is overlapping, generate until it is not
    while position in positions:
      position = round(random.randint(20, width - 20), -1), round(random.randint(20, height - 20), -1)

    # pick a random character to be generated
    character = random.choice(FOOD_CHARS)
    self.food = self.canvas.create_text(position, text=character)

    # store the previously generated character
    self.food_position = position
    self.food_character = character

  # When the timer ticks (updating the game)
  def tick(self):
    # get the canvas' width & height
    width = self.canvas.winfo_width()
    height = self.canvas.winfo_height()
    previous_head_position = tuple(self.head_position)

    # move the snake
    if self.direction == "w":
      self.head_position[1] -= 10
    elif self.direction == "a":
      self.head_position[0] -= 10
    elif self.direction == "s":
      self.head_position[1] += 10
    elif self.direction == "d":
      self.head_position[0] += 10

    # check if the game is over
    head_position = tuple(self.head_position)
    if(head_position[0] < 10 or head_position[0] >= width - 10 or head_position[1] < 10 or head_position[1] >= height - 10 or any(segments_position == head_position for segments_position in self.segments_positions)):
      self.game_over()
      return

    # Check if snake eats the food
    if head_position == self.food_position:
      self.canvas.coords(self.food, previous_head_position)
      self.segments.append(self.food)
      self.segments_positions.append(previous_head_position)
      self.spawn_food()

    # Make the food following the snake's head
    if self.segments:
      previous_position = previous_head_position
      for index, (segment, position) in enumerate(zip(self.segments, self.segments_positions)):
        self.canvas.coords(segment, previous_position)
        self.segments_positions[index] = previous_position
        previous_position = position

    # Put the new head's position into head_position
    self.canvas.coords(self.head, head_position)
    self.moved = True

    # change level (level up according to length of snake)
    speed = 100

    if len(self.segments) > 5:
      speed = 75

    if len(self.segments) > 10:
      speed = 60

    if len(self.segments) > 20:
      speed = 45

    # Call the tick function to update again after a certain time
    if self.running:
      self.canvas.after(speed, self.tick)

    display_speed = 10000 / speed
    self.start_button.configure(text = "Speed: %d" %display_speed)

  # Function for game over screen
  def game_over(self):
    # get tbe canvas' width & height
    width = self.canvas.winfo_width()
    height = self.canvas.winfo_height()

    # stop the game from running
    self.running = False

    # change the button's text to "start"
    self.start_button.configure(text="Start")

    # display the game over message & show the score
    score = len(self.segments) * 10
    self.canvas.create_text(round(width/2), round(height/2), text="Game Over! Your score is: %d" %score)

  # Function for 4 inputs
  def on_up(self, event):
    if self.moved and not self.direction == "s":
      self.direction = "w"
      self.moved = False

  def on_down(self,event):
    if self.moved and not self.direction == "w":
      self.direction = "s"
      self.moved = False

  def on_left(self, event):
    if self.moved and not self.direction == "d":
      self.direction = "a"
      self.moved = False

  def on_right(self, event):
    if self.moved and not self.direction == "a":
      self.direction = "d"
      self.moved = False

# Declaring the main loop (outside of any classes)
def snake():
  root = Tk()
  Application(root)
  root.mainloop()




from setuptools import setup, find_packages

setup(
    name="guimadeeasy",
    version="1.1",
    description="this is just a fun challenge for my friend",
    packages=['guimadeeasy'],
    long_description="""

    This is my first package, I think these GUIs are super safe. Prove me wrong :->

    Examples - 

    >>> from guimadeeasy import *
    >>> clock()
    
    >>> from guidmadeasy import *
    >>> wheather()

    >>> from guimadeeasy import *
    >>> calculator()

    >>> from guimadeeasy import *
    >>> notepad()

    >>> from guimadeeasy import *
    >>> todo()

    >>> from guimadeeasy import *
    >>> snake()"""
)



#!/usr/bin/python3

from guimadeeasy.calculator import *
from guimadeeasy.notepad import *
from guimadeeasy.todo import *
from guimadeeasy.wheather import *
from guimadeeasy.snake import *
from guimadeeasy.awesomeclock import *
